pub struct GlobalSearchBuilder { /* private fields */ }Available on crate feature
experimental-search only.Expand description
A builder for a global search Stream that allows configuring the initial
working set of rooms to search in.
Implementations
Sourceimpl GlobalSearchBuilder
impl GlobalSearchBuilder
Sourcepub async fn only_dm_rooms(self) -> Result<Self, Error>
pub async fn only_dm_rooms(self) -> Result<Self, Error>
Keep only the DM rooms from the initial working set.
Sourcepub async fn no_dms(self) -> Result<Self, Error>
pub async fn no_dms(self) -> Result<Self, Error>
Keep only non-DM rooms (groups) from the initial working set.
Sourcepub fn build(
self,
) -> impl Stream<Item = Result<Vec<(OwnedRoomId, f32, OwnedEventId)>, IndexError>>
pub fn build( self, ) -> impl Stream<Item = Result<Vec<(OwnedRoomId, f32, OwnedEventId)>, IndexError>>
Build a stream over the search results across all the rooms in the
working set, yielding pages of (room_id, score, event_id) tuples
sorted by descending relevance score.
Sourcepub fn build_events(
self,
) -> impl Stream<Item = Result<Vec<(OwnedRoomId, TimelineEvent)>, SearchError>>
pub fn build_events( self, ) -> impl Stream<Item = Result<Vec<(OwnedRoomId, TimelineEvent)>, SearchError>>
Same as Self::build, but yields pages of full TimelineEvents
instead of event IDs, by loading them from the store or from the
network.