pub struct GlobalSearchIterator { /* private fields */ }Available on crate feature
experimental-search only.Expand description
An async iterator for a search query across multiple rooms.
Implementations
Sourceimpl GlobalSearchIterator
impl GlobalSearchIterator
Sourcepub async fn next(
&mut self,
) -> Result<Option<Vec<(OwnedRoomId, OwnedEventId)>>, SearchError>
pub async fn next( &mut self, ) -> Result<Option<Vec<(OwnedRoomId, OwnedEventId)>>, SearchError>
Return the next batch of event IDs matching the search query across all
rooms, or None if there are no more results.
Sourcepub async fn next_events(
&mut self,
) -> Result<Option<Vec<(OwnedRoomId, TimelineEvent)>>, SearchError>
pub async fn next_events( &mut self, ) -> Result<Option<Vec<(OwnedRoomId, TimelineEvent)>>, SearchError>
Returns TimelineEvents instead of event IDs, by loading the events
from the store or from network.